@@ -13,12 +13,13 @@ class Facade(object):
     """
 
     def __init__(self):
-        self.gateway = gateway.Gateway(settings.DATACASH_HOST,
-                                       settings.DATACASH_CLIENT,
-                                       settings.DATACASH_PASSWORD,
-                                       getattr(settings, 'DATACASH_USE_CV2AVS', False),
-                                       getattr(settings, 'DATACASH_CAPTURE_METHOD', 'ecomm')
-                                      )
+        self.gateway = gateway.Gateway(
+            settings.DATACASH_HOST,
+            getattr(settings, 'DATACASH_PATH', '/Transaction'),
+            settings.DATACASH_CLIENT,
+            settings.DATACASH_PASSWORD,
+            getattr(settings, 'DATACASH_USE_CV2AVS', False),
+            getattr(settings, 'DATACASH_CAPTURE_METHOD', 'ecomm'))
         self.currency = settings.DATACASH_CURRENCY
 
     def handle_response(self, method, order_number, amount, response):
@@ -51,9 +52,11 @@ class Facade(object):
     def get_friendly_error_message(self, response):
         # TODO: expand this dict to handle the most common errors
         errors = {
+            56: ('This transaction was submitted too soon after the '
+                 'previous one.  Please wait for a minute then try again'),
             19: 'Unable to fulfill transaction',
         }
-        default_msg =  'An error occurred when communicating with the payment gateway.'
+        default_msg = 'An error occurred when communicating with the payment gateway.'
         return errors.get(response.status, default_msg)
 
     def extract_address_data(self, address):
@@ -72,31 +75,38 @@ class Facade(object):
     # ========================
 
     def pre_authorise(self, order_number, amount, bankcard=None,
-                      txn_reference=None, billing_address=None):
+                      txn_reference=None, billing_address=None,
+                      the3rdman_data=None):
         """
-        Ring-fence an amount of money from the given card.  This is the first stage
-        of a two-stage payment process.  A further call to fulfill is required to
-        debit the money.
+        Ring-fence an amount of money from the given card.  This is the first
+        stage of a two-stage payment process.  A further call to fulfill is
+        required to debit the money.
+
+        As there are SO MANY values that can be submitted to 3rdMan, a separate
+        dict of data must be submitted as a kwarg.
         """
         if amount == 0:
             raise UnableToTakePayment("Order amount must be non-zero")
         merchant_ref = self.merchant_reference(order_number, gateway.PRE)
         address_data = self.extract_address_data(billing_address)
         if bankcard:
-            response = self.gateway.pre(card_number=bankcard.card_number,
-                                        expiry_date=bankcard.expiry_date,
-                                        amount=amount,
-                                        currency=self.currency,
-                                        merchant_reference=merchant_ref,
-                                        ccv=bankcard.ccv,
-                                        **address_data
-                                        )
+            response = self.gateway.pre(
+                card_number=bankcard.card_number,
+                expiry_date=bankcard.expiry_date,
+                amount=amount,
+                currency=self.currency,
+                merchant_reference=merchant_ref,
+                ccv=bankcard.ccv,
+                the3rdman_data=the3rdman_data,
+                **address_data)
         elif txn_reference:
-            response = self.gateway.pre(amount=amount,
-                                        currency=self.currency,
-                                        merchant_reference=merchant_ref,
-                                        previous_txn_reference=txn_reference,
-                                        **address_data)
+            response = self.gateway.pre(
+                amount=amount,
+                currency=self.currency,
+                merchant_reference=merchant_ref,
+                previous_txn_reference=txn_reference,
+                the3rdman_data=the3rdman_data,
+                **address_data)
         else:
             raise ValueError("You must specify either a bankcard or a previous txn reference")
         return self.handle_response(gateway.PRE, order_number, amount, response)
@@ -147,7 +157,7 @@ class Facade(object):
     # ========================
 
     def authorise(self, order_number, amount, bankcard=None, txn_reference=None,
-                  billing_address=None):
+                  billing_address=None, the3rdman_data=None):
         """
         Debit a bankcard for the given amount
 
@@ -166,12 +176,14 @@ class Facade(object):
                                          currency=self.currency,
                                          merchant_reference=merchant_ref,
                                          ccv=bankcard.ccv,
+                                         the3rdman_data=the3rdman_data,
                                          **address_data)
         elif txn_reference:
             response = self.gateway.auth(amount=amount,
                                          currency=self.currency,
                                          merchant_reference=merchant_ref,
                                          previous_txn_reference=txn_reference,
+                                         the3rdman_data=the3rdman_data,
                                          **address_data)
         else:
             raise ValueError("You must specify either a bankcard or a previous txn reference")
