@@ -3,6 +3,7 @@ from xml.dom.minidom import parseString
 import urlparse
 
 from django.db import models
+from django.conf import settings
 
 from .the3rdman import signals
 
@@ -90,7 +91,7 @@ class FraudResponse(models.Model):
     aggregator_identifier = models.CharField(max_length=15, blank=True)
     merchant_identifier = models.CharField(max_length=15)
     merchant_order_ref = models.CharField(max_length=250, db_index=True)
-    t3m_id = models.CharField(max_length=128, unique=True)
+    t3m_id = models.CharField(max_length=128, db_index=True)
     score = models.IntegerField()
 
     RELEASE, HOLD, REJECT, UNDER_INVESTIGATION = 0, 1, 2, 9
@@ -184,3 +185,13 @@ class FraudResponse(models.Model):
             self.UNDER_INVESTIGATION: "Under investigation",
         }
         return mapping.get(self.recommendation, "Unknown")
+
+    @property
+    def gatekeeper_url(self):
+        """
+        Return the transaction detail URL on the Gatekeeper site
+        """
+        is_live = 'mars' in settings.DATACASH_HOST
+        host = 'cnpanalyst.com' if is_live else 'test.cnpanalyst.com'
+        return 'https://%s/TransactionDetails.aspx?TID=%s' % (
+            host, self.t3m_id)
